==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/d86/town__type_8h.js <==
var town__type_8h =
[
    [ "EnumPropsT< TownSize >", "da/d36/structEnumPropsT_3_01TownSize_01_4.html", null ],
    [ "EnumPropsT< TownLayout >", "df/df8/structEnumPropsT_3_01TownLayout_01_4.html", null ],
    [ "TransportedCargoStat", "dd/d9d/structTransportedCargoStat.html", "dd/d9d/structTransportedCargoStat" ],
    [ "TownFoundingByte", "d9/d86/town__type_8h.html#a376d0fa499d77627ad098232b253d3b2", null ],
    [ "TownID", "d9/d86/town__type_8h.html#a0b891543e8fb74d1cd5c58a2982ff29d", null ],
    [ "TownLayoutByte", "d9/d86/town__type_8h.html#aac1133cf91d0717d5fdb0712378be3d9", null ],
    [ "Ratings", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3", [
      [ "RATING_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3aeffde13e513ae9b4e9967f3ada0420a9", null ],
      [ "RATING_APPALLING", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a2f43bdf217c544c61e146f9f3eacc36f", null ],
      [ "RATING_VERYPOOR", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3abfb46f2cfb547573349b1a911dc035f6", null ],
      [ "RATING_POOR", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a336f29a8ce441ce6264ef832fe77d86b", null ],
      [ "RATING_MEDIOCRE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3acb2c38289b6759a736c7b66fb92539b1", null ],
      [ "RATING_GOOD", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3aec19573ff8110059dc882e500bdc6820", null ],
      [ "RATING_VERYGOOD", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3abc2cd9f4f4b8baab244ebddd4086c744", null ],
      [ "RATING_EXCELLENT", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ad167486eb8a469622940e1ab831b62cc", null ],
      [ "RATING_OUTSTANDING", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a4147a446d3559d20e4b6e49c096f3b6d", null ],
      [ "RATING_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a970daf4c391fc93cc5c23d0583d0d375", null ],
      [ "RATING_INITIAL", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a454cd9cea442725b851be564ae886eb4", null ],
      [ "RATING_TREE_DOWN_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a541a7e59eee6a99f02819f3cd25ffc2d", null ],
      [ "RATING_TREE_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3aa7039e1454074bbabaa697a7c551e2ba", null ],
      [ "RATING_TREE_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a35345ce47127687fad7f46395bd31522", null ],
      [ "RATING_TREE_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a4e64a76456e646303d649715124f94b8", null ],
      [ "RATING_GROWTH_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3af90120073182336bd2e9ab2ff4a35343", null ],
      [ "RATING_GROWTH_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3adcf1de2246385698692e3c57941eac02", null ],
      [ "RATING_STATION_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ab2d1aa18e3e9a3283d7e8776a667685a", null ],
      [ "RATING_STATION_DOWN_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1986667ace50736e23efac07e6eeba0a", null ],
      [ "RATING_TUNNEL_BRIDGE_DOWN_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a27980a585a6186da7310c833b5e91f53", null ],
      [ "RATING_TUNNEL_BRIDGE_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ac962e9ab342df7277d1bd52f9cb09e94", null ],
      [ "RATING_TUNNEL_BRIDGE_NEEDED_PERMISSIVE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3acff2a0bc6843f22e489c05e711d9ea28", null ],
      [ "RATING_TUNNEL_BRIDGE_NEEDED_NEUTRAL", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1f7657bf9ba42493c6f1d932509de7be", null ],
      [ "RATING_TUNNEL_BRIDGE_NEEDED_HOSTILE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a2a29a642561716a31bc407f56b018ad9", null ],
      [ "RATING_ROAD_DOWN_STEP_INNER", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a983e9096a7092c974a143f8fa892a473", null ],
      [ "RATING_ROAD_DOWN_STEP_EDGE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1e824085660c99585ea6f94604f53b34", null ],
      [ "RATING_ROAD_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ad815c1bf46ccbe30da7f3b1269d98980", null ],
      [ "RATING_ROAD_NEEDED_PERMISSIVE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a902e9f206981db1b4037f406cff22611", null ],
      [ "RATING_ROAD_NEEDED_NEUTRAL", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3afdaa38768e9e59011328b4caa8bca711", null ],
      [ "RATING_ROAD_NEEDED_HOSTILE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a570d705ec322a56c49487c629f0f7039", null ],
      [ "RATING_HOUSE_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1842ef0e1081386fb4a60f22dc94d3f4", null ],
      [ "RATING_BRIBE_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a9a480396fb9317f6d6b72595b9bdb105", null ],
      [ "RATING_BRIBE_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3abb87306c82e689aaaf0287dcf423ee11", null ],
      [ "RATING_BRIBE_DOWN_TO", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a2bc9500abb17808f2e5c32ea7f9efbe0", null ]
    ] ],
    [ "TownFounding", "d9/d86/town__type_8h.html#ad8d44d090a55f8c1fd3b5955faeecb0e", [
      [ "TF_BEGIN", "d9/d86/town__type_8h.html#ad8d44d090a55f8c1fd3b5955faeecb0eab25a8a8a083c96a97fbaa41a05d0e7b8", null ],
      [ "TF_FORBIDDEN", "d9/d86/town__type_8h.html#ad8d44d090a55f8c1fd3b5955faeecb0eacd63e0cae4b610de5b8cc8fbcb95ac05", null ],
      [ "TF_ALLOWED", "d9/d86/town__type_8h.html#ad8d44d090a55f8c1fd3b5955faeecb0ea0f9c5a8a21b1f91074a05ce7d295ee7b", null ],
      [ "TF_CUSTOM_LAYOUT", "d9/d86/town__type_8h.html#ad8d44d090a55f8c1fd3b5955faeecb0ea6777dc221e7332eb420c4078b942e13a", null ],
      [ "TF_END", "d9/d86/town__type_8h.html#ad8d44d090a55f8c1fd3b5955faeecb0ea6c5df92ef25bd7abf714ac65c75c6af9", null ]
    ] ],
    [ "TownLayout", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acb", [
      [ "TL_BEGIN", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acbad9d272dfba4db17dfec89071b1db35d5", null ],
      [ "TL_ORIGINAL", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acba49d3ca4ca3bb9a3cf4fad38a1dce7bf9", null ],
      [ "TL_BETTER_ROADS", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acbabce53eea2c12324c57b14435f29652b9", null ],
      [ "TL_2X2_GRID", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acba833128879cbf956723e5535f6c3bdf31", null ],
      [ "TL_3X3_GRID", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acba2c72dfe9ad3f9bdc5c095f89de6405f1", null ],
      [ "TL_RANDOM", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acba847e7ba0166714c800626b2275f975f7", null ],
      [ "NUM_TLS", "d9/d86/town__type_8h.html#a7265ebbcc81aaf1c5c61b244386d2acbad29ec2ca08de833152148b8000b3c9c1", null ]
    ] ],
    [ "TownSize", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fc", [
      [ "TSZ_SMALL", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fcae784817c02ebee0d2a8be66d16395845", null ],
      [ "TSZ_MEDIUM", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fca834f6efbe6ad981783ca44edab4c4d99", null ],
      [ "TSZ_LARGE", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fcaf01fdc6a760c3b603adf76922f0c6db2", null ],
      [ "TSZ_RANDOM", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fca4e7e22497401eec73556d7a3936105ab", null ],
      [ "TSZ_END", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fca6fc96beae36df40614fdf49ba8a17db8", null ]
    ] ],
    [ "MAX_LENGTH_TOWN_NAME_CHARS", "d9/d86/town__type_8h.html#ad5bf470f044e0fbe18e86e72cbdcbc9d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/d86/town__type_8h.js <==
var town__type_8h =
[
    [ "EnumPropsT< TownSize >", "da/d36/structEnumPropsT_3_01TownSize_01_4.html", null ],
    [ "EnumPropsT< TownLayout >", "df/df8/structEnumPropsT_3_01TownLayout_01_4.html", null ],
    [ "TransportedCargoStat", "dd/d9d/structTransportedCargoStat.html", "dd/d9d/structTransportedCargoStat" ],
    [ "TownID", "d9/d86/town__type_8h.html#a0b891543e8fb74d1cd5c58a2982ff29d", null ],
    [ "Ratings", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3", [
      [ "RATING_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3aeffde13e513ae9b4e9967f3ada0420a9", null ],
      [ "RATING_APPALLING", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a2f43bdf217c544c61e146f9f3eacc36f", null ],
      [ "RATING_VERYPOOR", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3abfb46f2cfb547573349b1a911dc035f6", null ],
      [ "RATING_POOR", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a336f29a8ce441ce6264ef832fe77d86b", null ],
      [ "RATING_MEDIOCRE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3acb2c38289b6759a736c7b66fb92539b1", null ],
      [ "RATING_GOOD", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3aec19573ff8110059dc882e500bdc6820", null ],
      [ "RATING_VERYGOOD", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3abc2cd9f4f4b8baab244ebddd4086c744", null ],
      [ "RATING_EXCELLENT", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ad167486eb8a469622940e1ab831b62cc", null ],
      [ "RATING_OUTSTANDING", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a4147a446d3559d20e4b6e49c096f3b6d", null ],
      [ "RATING_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a970daf4c391fc93cc5c23d0583d0d375", null ],
      [ "RATING_INITIAL", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a454cd9cea442725b851be564ae886eb4", null ],
      [ "RATING_TREE_DOWN_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a541a7e59eee6a99f02819f3cd25ffc2d", null ],
      [ "RATING_TREE_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3aa7039e1454074bbabaa697a7c551e2ba", null ],
      [ "RATING_TREE_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a35345ce47127687fad7f46395bd31522", null ],
      [ "RATING_TREE_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a4e64a76456e646303d649715124f94b8", null ],
      [ "RATING_GROWTH_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3af90120073182336bd2e9ab2ff4a35343", null ],
      [ "RATING_GROWTH_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3adcf1de2246385698692e3c57941eac02", null ],
      [ "RATING_STATION_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ab2d1aa18e3e9a3283d7e8776a667685a", null ],
      [ "RATING_STATION_DOWN_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1986667ace50736e23efac07e6eeba0a", null ],
      [ "RATING_TUNNEL_BRIDGE_DOWN_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a27980a585a6186da7310c833b5e91f53", null ],
      [ "RATING_TUNNEL_BRIDGE_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ac962e9ab342df7277d1bd52f9cb09e94", null ],
      [ "RATING_TUNNEL_BRIDGE_NEEDED_PERMISSIVE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3acff2a0bc6843f22e489c05e711d9ea28", null ],
      [ "RATING_TUNNEL_BRIDGE_NEEDED_NEUTRAL", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1f7657bf9ba42493c6f1d932509de7be", null ],
      [ "RATING_TUNNEL_BRIDGE_NEEDED_HOSTILE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a2a29a642561716a31bc407f56b018ad9", null ],
      [ "RATING_ROAD_DOWN_STEP_INNER", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a983e9096a7092c974a143f8fa892a473", null ],
      [ "RATING_ROAD_DOWN_STEP_EDGE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1e824085660c99585ea6f94604f53b34", null ],
      [ "RATING_ROAD_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3ad815c1bf46ccbe30da7f3b1269d98980", null ],
      [ "RATING_ROAD_NEEDED_PERMISSIVE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a902e9f206981db1b4037f406cff22611", null ],
      [ "RATING_ROAD_NEEDED_NEUTRAL", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3afdaa38768e9e59011328b4caa8bca711", null ],
      [ "RATING_ROAD_NEEDED_HOSTILE", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a570d705ec322a56c49487c629f0f7039", null ],
      [ "RATING_HOUSE_MINIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a1842ef0e1081386fb4a60f22dc94d3f4", null ],
      [ "RATING_BRIBE_UP_STEP", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a9a480396fb9317f6d6b72595b9bdb105", null ],
      [ "RATING_BRIBE_MAXIMUM", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3abb87306c82e689aaaf0287dcf423ee11", null ],
      [ "RATING_BRIBE_DOWN_TO", "d9/d86/town__type_8h.html#aa5690e3a1bddd51eb0a3cea53c3dfaa3a2bc9500abb17808f2e5c32ea7f9efbe0", null ]
    ] ],
    [ "TownCargoGenMode", "d9/d86/town__type_8h.html#ac0c8a7348fdafc522067a4d27bf3b44e", [
      [ "TCGM_BEGIN", "d9/d86/town__type_8h.html#ac0c8a7348fdafc522067a4d27bf3b44eae941d739859ef7a8ce5881339df704ab", null ],
      [ "TCGM_ORIGINAL", "d9/d86/town__type_8h.html#ac0c8a7348fdafc522067a4d27bf3b44eaf0991c8d1cb4d3ac8a4565244df59464", null ],
      [ "TCGM_BITCOUNT", "d9/d86/town__type_8h.html#ac0c8a7348fdafc522067a4d27bf3b44ea09681c09192bb2c4b58eb02a39e939de", null ],
      [ "TCGM_END", "d9/d86/town__type_8h.html#ac0c8a7348fdafc522067a4d27bf3b44ead232756b4d1f050da3ef122ba99ca5e4", null ]
    ] ],
    [ "TownFounding", "d9/d86/town__type_8h.html#a16472d97ae96ab25c983ea03fbc66937", [
      [ "TF_BEGIN", "d9/d86/town__type_8h.html#a16472d97ae96ab25c983ea03fbc66937ab25a8a8a083c96a97fbaa41a05d0e7b8", null ],
      [ "TF_FORBIDDEN", "d9/d86/town__type_8h.html#a16472d97ae96ab25c983ea03fbc66937acd63e0cae4b610de5b8cc8fbcb95ac05", null ],
      [ "TF_ALLOWED", "d9/d86/town__type_8h.html#a16472d97ae96ab25c983ea03fbc66937a0f9c5a8a21b1f91074a05ce7d295ee7b", null ],
      [ "TF_CUSTOM_LAYOUT", "d9/d86/town__type_8h.html#a16472d97ae96ab25c983ea03fbc66937a6777dc221e7332eb420c4078b942e13a", null ],
      [ "TF_END", "d9/d86/town__type_8h.html#a16472d97ae96ab25c983ea03fbc66937a6c5df92ef25bd7abf714ac65c75c6af9", null ]
    ] ],
    [ "TownLayout", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265", [
      [ "TL_BEGIN", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265ad9d272dfba4db17dfec89071b1db35d5", null ],
      [ "TL_ORIGINAL", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265a49d3ca4ca3bb9a3cf4fad38a1dce7bf9", null ],
      [ "TL_BETTER_ROADS", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265abce53eea2c12324c57b14435f29652b9", null ],
      [ "TL_2X2_GRID", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265a833128879cbf956723e5535f6c3bdf31", null ],
      [ "TL_3X3_GRID", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265a2c72dfe9ad3f9bdc5c095f89de6405f1", null ],
      [ "TL_RANDOM", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265a847e7ba0166714c800626b2275f975f7", null ],
      [ "NUM_TLS", "d9/d86/town__type_8h.html#a1808580828500bfef6905cb92b121265ad29ec2ca08de833152148b8000b3c9c1", null ]
    ] ],
    [ "TownSize", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fc", [
      [ "TSZ_SMALL", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fcae784817c02ebee0d2a8be66d16395845", null ],
      [ "TSZ_MEDIUM", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fca834f6efbe6ad981783ca44edab4c4d99", null ],
      [ "TSZ_LARGE", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fcaf01fdc6a760c3b603adf76922f0c6db2", null ],
      [ "TSZ_RANDOM", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fca4e7e22497401eec73556d7a3936105ab", null ],
      [ "TSZ_END", "d9/d86/town__type_8h.html#a7223d5c8194918628aba562df0f968fca6fc96beae36df40614fdf49ba8a17db8", null ]
    ] ],
    [ "MAX_LENGTH_TOWN_NAME_CHARS", "d9/d86/town__type_8h.html#ad5bf470f044e0fbe18e86e72cbdcbc9d", null ]
];
